@@ -14,7 +14,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with readBrukerFlexData. If not, see <http://www.gnu.org/licenses/>
+## along with readBrukerFlexData. If not, see <https://www.gnu.org/licenses/>
 
 #' Reads an acqu file.
 #'
@@ -135,15 +135,17 @@
 ##
 .readAcquFile <- function(fidFile, verbose=FALSE) {
   acquFile <- sub(pattern="fid$", x=fidFile, replacement="acqu")
-
-  if (verbose) {
-    message("Reading metadata from ", sQuote(acquFile), " ...")
-  }
+  acquFiles <- c(acquFile, paste0(acquFile, "s"))
+  acquFile <- acquFiles[which.max(file.exists(acquFiles))]
 
   if (!file.exists(acquFile)) {
     stop("File ", sQuote(acquFile), " doesn't exists!")
   }
 
+  if (verbose) {
+    message("Reading metadata from ", sQuote(acquFile), " ...")
+  }
+
   con <- file(acquFile, "rt")
   acquLines <- readLines(con, n=-1)
   close(con)
@@ -187,9 +189,14 @@
   }
 
   # https://github.com/sgibb/MALDIquantForeign/issues/19
+  # https://github.com/sgibb/readBrukerFlexData/issues/3
   metaData$v1tofCalibration <-
     grepl("V1.0CTOF2CalibrationConstants",
           .grepAcquValue("##\\$NTBCal=", acquLines))
+  metaData$v1tofCalibrationConstants <-
+    .extractV10CTOF2CalibrationConstants(
+      .grepAcquValue("##\\$NTBCal=", acquLines)
+    )
 
   ## obligate LIFT
   metaData$lift <- c(.grepAcquDoubleValue("##\\$Lift1=", acquLines),
